import { CloudFormation } from '@aws-sdk/client-cloudformation';
import { CognitoIdentityProvider } from '@aws-sdk/client-cognito-identity-provider';
import { DynamoDB } from '@aws-sdk/client-dynamodb';
import { EC2 } from '@aws-sdk/client-ec2';
import { EC2InstanceConnect } from '@aws-sdk/client-ec2-instance-connect';
import { EventBridge } from '@aws-sdk/client-eventbridge';
import { IAM } from '@aws-sdk/client-iam';
import { KMS } from '@aws-sdk/client-kms';
import { Lambda } from '@aws-sdk/client-lambda';
import { S3 } from '@aws-sdk/client-s3';
import { S3Control } from '@aws-sdk/client-s3-control';
import { SageMaker } from '@aws-sdk/client-sagemaker';
import { ServiceCatalog } from '@aws-sdk/client-service-catalog';
import { ServiceCatalogAppRegistry } from '@aws-sdk/client-service-catalog-appregistry';
import { ServiceQuotas } from '@aws-sdk/client-service-quotas';
import { SSM } from '@aws-sdk/client-ssm';
import { STS } from '@aws-sdk/client-sts';
import { Credentials } from '@aws-sdk/types';
import AppRegistryService from './helpers/appRegistryService';
import CloudformationService from './helpers/cloudformationService';
import CognitoService from './helpers/cognitoService';
import DynamoDBService from './helpers/dynamoDB/dynamoDBService';
import S3Service from './helpers/s3Service';
import ServiceCatalogService from './helpers/serviceCatalogService';
export default class AwsService {
    clients: {
        cloudformation: CloudFormation;
        cognito: CognitoIdentityProvider;
        ssm: SSM;
        ec2: EC2;
        ec2InstanceConnect: EC2InstanceConnect;
        eventBridge: EventBridge;
        serviceCatalog: ServiceCatalog;
        s3: S3;
        sts: STS;
        iam: IAM;
        ddb: DynamoDB;
        s3Control: S3Control;
        lambda: Lambda;
        sagemaker: SageMaker;
        kms: KMS;
        appRegistry: ServiceCatalogAppRegistry;
        serviceQuotas: ServiceQuotas;
    };
    helpers: {
        cloudformation: CloudformationService;
        s3: S3Service;
        ddb: DynamoDBService;
        serviceCatalog: ServiceCatalogService;
        appRegistryService: AppRegistryService;
        cognito: CognitoService;
    };
    constructor(options: {
        region: string;
        ddbTableName?: string;
        userAgent?: string;
        credentials?: Credentials;
    });
    getAwsServiceForRole(params: {
        roleArn: string;
        roleSessionName: string;
        externalId?: string;
        region: string;
    }): Promise<AwsService>;
}
//# sourceMappingURL=awsService.d.ts.map