"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class AppRegistryService {
    constructor(appRegistry, cloudFormation, serviceQuotas) {
        this._appRegistry = appRegistry;
        this._cloudFormation = cloudFormation;
        this._serviceQuotas = serviceQuotas;
    }
    /*
     * Associate stack resource to App registry Application
     */
    async associateStackToAppRegistry(appRegistryName, stackName) {
        try {
            console.log(`Associating Stack: ${stackName} to App Registry: ${appRegistryName}`);
            const applicationDetails = await this._appRegistry.getApplication({ application: appRegistryName });
            const stackDetails = await this._cloudFormation.describeStacks({ StackName: stackName });
            const stackFound = stackDetails.Stacks[0];
            const applicationId = applicationDetails.id;
            console.log(`Associating Stack: ${stackFound.StackId} to App Registry: ${applicationId}`);
            console.log(`Associated Resource Count: ${applicationDetails.associatedResourceCount}`);
            const appRegistrationQuota = await this._serviceQuotas.getServiceQuota({
                ServiceCode: 'servicecatalog',
                QuotaCode: 'L-360CDF2E'
            }); //service catalog app registry resource count
            const resourceLimit = appRegistrationQuota.Quota.Value;
            console.log(`Resource Limit: ${resourceLimit}`);
            if (applicationDetails.associatedResourceCount + 1 > resourceLimit) {
                throw new Error('App Registry Limit has been reached');
            }
            await this._appRegistry.associateResource({
                application: applicationId,
                resourceType: 'CFN_STACK',
                resource: stackFound.StackId
            }); //if resource is already associated, a conflict exception will throw
        }
        catch (e) {
            console.error(`Could not associate resource: [${stackName}] to application: [${appRegistryName}] - ${e.message}`); //catch all exceptions to avoid blocking users from creating workspaces
        }
    }
    /*
     * Disssociate stack resource to App registry Application
     */
    async disassociateStackToAppRegistry(appRegistryName, stackName) {
        try {
            console.log(`Disassociating Stack: ${stackName} to App Registry: ${appRegistryName}`);
            const applicationDetails = await this._appRegistry.getApplication({ application: appRegistryName });
            const stackDetails = await this._cloudFormation.describeStacks({ StackName: stackName });
            const stackFound = stackDetails.Stacks[0];
            const applicationId = applicationDetails.id;
            console.log(`Disassociating Stack: ${stackFound.StackId} to App Registry: ${applicationId}`);
            console.log(`Associated Resource Count: ${applicationDetails.associatedResourceCount}`);
            await this._appRegistry.disassociateResource({
                application: applicationId,
                resourceType: 'CFN_STACK',
                resource: stackFound.StackId
            }); //if resource is not associated, a exception will throw
        }
        catch (e) {
            console.error(`Could not disassociate resource: [${stackName}] to application: [${appRegistryName}] - ${e.message}`); //catch all exceptions to avoid blocking users from terminating workspaces
        }
    }
}
exports.default = AppRegistryService;
//# sourceMappingURL=appRegistryService.js.map