import { AttributeValue, TransactWriteItemsCommandInput, TransactWriteItemsCommandOutput } from '@aws-sdk/client-dynamodb';
/**
 * This class helps with batch writes or deletes.
 */
declare class TransactEdit {
    private _ddb;
    private _params;
    private _tableName;
    constructor(config: {
        region: string;
    }, table: string);
    /**
     *
     * @param items - Object of the items to add
     */
    addPutItems(items: Record<string, AttributeValue>[]): TransactEdit;
    /**
     * Add put requests
     * @param putRequests - A list of put request to add
     * @returns
     */
    addPutRequests(putRequests: {
        item: Record<string, AttributeValue>;
        conditionExpression?: string;
        expressionAttributeNames?: Record<string, string>;
        expressionAttributeValues?: Record<string, AttributeValue>;
    }[]): TransactEdit;
    /**
     * Add one or more delete request(s) to the command input. Use to delete one or more items from a DynamoDB Table.
     *
     * @param keys - list of object(s) of the primary key(s) of item(s) to delete
     * @returns TransactEdit item with populated params
     */
    addDeleteRequests(keys: Record<string, AttributeValue>[]): TransactEdit;
    /**
     * Add a single delete request to the command input. Use to delete a single item from a DynamoDB Table.
     *
     * @param key - object of the primary key of item to delete
     * @returns TransactEdit item with populated params
     */
    addDeleteRequest(key: Record<string, AttributeValue>): TransactEdit;
    /**
     * Gets the internal _params value of the command input.
     *
     * @returns The parameters for the TransactWriteItemsCommandInput
     */
    getParams(): TransactWriteItemsCommandInput;
    /**
     * Sends the internal parameters as input to the DynamoDB table to execute write request(s).
     * Call this after populating the command input params with the above methods.
     * If UnproccessedItems is non empty, some request failed.
     *
     * @returns The output from the transact write item command
     */
    execute(): Promise<TransactWriteItemsCommandOutput>;
}
export default TransactEdit;
//# sourceMappingURL=transactEdit.d.ts.map