"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
class ServiceCatalogService {
    constructor(serviceCatalog) {
        this._serviceCatalog = serviceCatalog;
    }
    /**
     * Get portfolioId of a portfolio
     * @param portfolioName - name of the portfolio
     */
    async getPortfolioId(portfolioName) {
        let portfolioDetails = [];
        let pageToken = undefined;
        // Get all portfolios in the account
        do {
            const listPortfolioInput = {
                PageToken: pageToken,
                PageSize: 20
            };
            const listPortfolioOutput = await this._serviceCatalog.listPortfolios(listPortfolioInput);
            pageToken = listPortfolioOutput.NextPageToken;
            if (listPortfolioOutput.PortfolioDetails) {
                portfolioDetails = portfolioDetails.concat(listPortfolioOutput.PortfolioDetails);
            }
        } while (pageToken);
        // Find the SWB portfolio
        const portfolio = portfolioDetails.find((portfolio) => {
            return portfolio.DisplayName === portfolioName;
        });
        return portfolio ? portfolio.Id : undefined;
    }
    /**
     * Get portfolio products
     * @param portfolioId - Id of the portfolio
     */
    async getProductsByPortfolioId(portfolioId) {
        let productsDetails = [];
        let pageToken = undefined;
        // Get all products within portfolio
        do {
            const productsFilter = {
                PageToken: pageToken,
                PageSize: 20,
                SortBy: 'CreationDate',
                SortOrder: 'DESCENDING',
                PortfolioId: portfolioId
            };
            const productList = await this._serviceCatalog.searchProductsAsAdmin(productsFilter);
            pageToken = productList.NextPageToken;
            if (productList.ProductViewDetails) {
                productsDetails = productsDetails.concat(productList.ProductViewDetails);
            }
        } while (pageToken);
        return productsDetails.filter((p) => !!p.ProductViewSummary).map((p) => p.ProductViewSummary || {});
    }
    /**
     * Get provision artifacts by product
     * @param productId - Id of the portfolio
     */
    async getProvisionArtifactsByProductId(productId) {
        const provisionArtifactList = await this._serviceCatalog.listProvisioningArtifacts({
            ProductId: productId
        });
        return provisionArtifactList.ProvisioningArtifactDetails || [];
    }
    /**
     * Get provision artifacts details
     * @param productId - Id of the product
     * @param provisionArtifactId - Id of the provision Artifact
     */
    async getProvisionArtifactDetails(productId, provisionArtifactId) {
        const provisionArtifactList = await this._serviceCatalog.describeProvisioningArtifact({
            ProductId: productId,
            ProvisioningArtifactId: provisionArtifactId
        });
        return provisionArtifactList;
    }
}
exports.default = ServiceCatalogService;
//# sourceMappingURL=serviceCatalogService.js.map