"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryStringParamFilterParser = void 0;
const textUtil_1 = require("../utilities/textUtil");
const validatorHelper_1 = require("../utilities/validatorHelper");
/************
 *
 * Only one operator can be defined by property, if multiple operators are defined, dynamo service will throw an exception.
 *
 ************/
const parameterFilterParser = validatorHelper_1.z
    .string()
    .max(textUtil_1.urlFilterMaxLength, { message: (0, textUtil_1.lengthValidationMessage)(textUtil_1.urlFilterMaxLength) });
// eslint-disable-next-line @rushstack/typedef-var
exports.QueryStringParamFilterParser = validatorHelper_1.z
    .object({
    eq: parameterFilterParser.optionalNonEmpty(),
    lt: parameterFilterParser.optionalNonEmpty(),
    lte: parameterFilterParser.optionalNonEmpty(),
    gt: parameterFilterParser.optionalNonEmpty(),
    gte: parameterFilterParser.optionalNonEmpty(),
    between: validatorHelper_1.z
        .object({
        value1: parameterFilterParser.required(),
        value2: parameterFilterParser.required()
    })
        .refine((data) => data.value1 <= data.value2, {
        message: textUtil_1.betweenFilterMessage
    })
        .optional(),
    begins: parameterFilterParser.optionalNonEmpty()
})
    .strict();
//# sourceMappingURL=queryStringParamFilter.js.map