import { ZodTypeAny } from 'zod';
import DynamoDBService from '../aws/helpers/dynamoDB/dynamoDBService';
import PaginatedResponse from '../interfaces/paginatedResponse';
import JSONValue from '../types/json';
export declare class MetadataService {
    private readonly _ddbService;
    constructor(ddbService: DynamoDBService);
    /************************************************************
     * Retrieves metadata relationships related to entity and metadata related to dependencies
     * @param mainEntityRequest - main Entity request object
     * @param dependencies - array of dependencies
     * @param mainMetadataMapper - function that parses main entity request and dependency entity to main entity metadata
     * @param dependencyMetadataMapper - function that parses main entity request and dependency entity to dependency metadata
     * @returns object containing main entity metadata and dependency metadata
     ************************************************************/
    getMetadataItems<EntityRequest, DependencyEntity, MainEntityMetadata, DependencyMetadata>(mainEntityRequest: EntityRequest, dependencies: DependencyEntity[], mainMetadataMapper: (mainEntityRequest: EntityRequest, dependencyEntity: DependencyEntity) => MainEntityMetadata, dependencyMetadataMapper?: (mainEntityRequest: EntityRequest, dependencyEntity: DependencyEntity) => DependencyMetadata): {
        mainEntityMetadata: MainEntityMetadata[];
        dependencyMetadata: DependencyMetadata[];
    };
    /**
     *
     * @param mainEntityResourceType - main entity resource type
     * @param mainEntityId - main entity id
     * @param dependencyResourceType - dependency resource type
     * @param parser - Zod parser for metadata object
     * @param queryParams - parameters to query metadata. Supported page size and pagination token.
     * @returns object containing list of metadata objects and continuation token.
     */
    listDependentMetadata<DependencyMetadata extends {
        pk: string;
        sk: string;
        id: string;
    }>(mainEntityResourceType: string, mainEntityId: string, dependencyResourceType: string, parser: ZodTypeAny, queryParams?: {
        pageSize?: number;
        paginationToken?: string;
    }): Promise<PaginatedResponse<DependencyMetadata>>;
    updateRelationship(mainEntityResourceType: string, mainEntity: {
        id: string;
        data?: Record<string, JSONValue>;
    }, dependencyResourceType: string, dependencies: {
        id: string;
        data?: Record<string, JSONValue>;
    }[]): Promise<void>;
    deleteRelationships(mainEntityResourceType: string, mainEntityId: string, dependencyResourceType: string, dependentIds: string[]): Promise<void>;
    /**
     * Retrieves a single instance of dependency metadata by Ids
     * @param mainEntityResourceType - main entity resource type
     * @param mainEntityId - main entity id
     * @param dependencyResourceType - dependency resource type
     * @param dependencyId - dependency entity id
     * @param parser - Zod parser for metadata object
     * @returns object with metadata information
     */
    getMetadataItem<DependencyMetadata extends {
        pk: string;
        sk: string;
        id: string;
    }>(mainEntityResourceType: string, mainEntityId: string, dependencyResourceType: string, dependencyId: string, parser: ZodTypeAny): Promise<DependencyMetadata | undefined>;
}
//# sourceMappingURL=metadataService.d.ts.map