"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MAX_API_PAGE_SIZE = exports.DEFAULT_API_PAGE_SIZE = exports.fromPaginationToken = exports.toPaginationToken = exports.getPaginationToken = exports.addPaginationToken = void 0;
const invalidPaginationTokenError_1 = require("../errors/invalidPaginationTokenError");
function addPaginationToken(paginationToken, queryParams) {
    const params = Object.assign({}, queryParams);
    // If paginationToken is defined, add param
    // from: https://notes.serverlessfirst.com/public/How+to+paginate+lists+returned+from+DynamoDB+through+an+API+endpoint#Implementing+this+in+code
    if (paginationToken) {
        params.start = fromPaginationToken(paginationToken);
    }
    return params;
}
exports.addPaginationToken = addPaginationToken;
function getPaginationToken(ddbQueryResponse) {
    return ddbQueryResponse.LastEvaluatedKey
        ? Buffer.from(JSON.stringify(ddbQueryResponse.LastEvaluatedKey)).toString('base64')
        : undefined;
}
exports.getPaginationToken = getPaginationToken;
/**
 * Function to convert an object of key-value string pairs to a pagination token.
 *
 * @param key - object of key-value pairs to convert to a pagination token
 * @returns string of a pagination token
 */
function toPaginationToken(key) {
    return Buffer.from(JSON.stringify(key)).toString('base64');
}
exports.toPaginationToken = toPaginationToken;
/**
 * Function to convert a pagination token to an object of key-value string pairs.
 *
 * @param token - pagination token to convert to an object of key-value string pairs
 * @returns object of key-value string pairs
 */
function fromPaginationToken(token) {
    try {
        return JSON.parse(Buffer.from(token, 'base64').toString('utf8'));
    }
    catch (_a) {
        throw new invalidPaginationTokenError_1.InvalidPaginationTokenError(`Invalid Pagination Token: ${token}`);
    }
}
exports.fromPaginationToken = fromPaginationToken;
exports.DEFAULT_API_PAGE_SIZE = 50;
exports.MAX_API_PAGE_SIZE = 1000;
//# sourceMappingURL=paginationHelper.js.map