"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSortQueryParams = exports.getFilterQueryParams = exports.validateSingleSortAndFilter = void 0;
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
const util_dynamodb_1 = require("@aws-sdk/util-dynamodb");
const Boom = __importStar(require("@hapi/boom"));
/************************************************************
 * Validates only one sorting or filter in list requests
 * @param filter - filter request object
 * @param sort - sorting request object
 ************************************************************/
function validateSingleSortAndFilter(filter, sort) {
    const filterAttributesLength = filter ? Object.keys(filter).length : 0;
    const sortAttributesLength = sort ? Object.keys(sort).length : 0;
    // Check that at most one filter is defined because we not support more than one filter
    if (filterAttributesLength > 1) {
        throw Boom.badRequest('Cannot apply more than one filter.');
    }
    // Check that at most one sort attribute is defined because we not support sorting by more than one attribute
    if (sortAttributesLength > 1) {
        throw Boom.badRequest('Cannot sort by more than one attribute.');
    }
    const hasSameProperty = filterAttributesLength === 1 &&
        sortAttributesLength === 1 &&
        Object.keys(filter !== null && filter !== void 0 ? filter : {})[0] === Object.keys(sort !== null && sort !== void 0 ? sort : {})[0];
    if (filter && sort && !hasSameProperty) {
        throw Boom.badRequest('Cannot apply a filter and sort to different properties at the same time');
    }
}
exports.validateSingleSortAndFilter = validateSingleSortAndFilter;
/************************************************************
 * Parses FilterRequest into QueryParam object consumed by dynamoDB
 *
 * @param filter - filter request object
 * @param gsiPropertyNames - field names on pascal case format to retrieve gsi name
 *
 * @returns QueryParams object
 ************************************************************/
function getFilterQueryParams(filter, gsiNames) {
    //validate filter request doesnt have more than one filter or no filters
    if (!filter || Object.keys(filter).length === 0) {
        return {};
    }
    if (Object.keys(filter).length > 1) {
        throw Boom.badRequest('Cannot filter by more than one attribute.');
    }
    //only one entry will exist due to validation above
    const { key, value } = Object.entries(filter).map(([key, value]) => {
        return { key, value };
    })[0];
    //transform { operator: value } into { operator { type: value } }
    const filterQueryParam = ((value === null || value === void 0 ? void 0 : value.between) ? { between: (0, util_dynamodb_1.marshall)(value.between) } : (0, util_dynamodb_1.marshall)(value));
    //get GSI from gsi list in params
    const gsiMatches = gsiNames.filter((prop) => prop.replace('getResourceBy', '').toLowerCase() === key.toLowerCase());
    const gsi = gsiMatches && gsiMatches.length > 0 ? gsiMatches[0] : '';
    //only return when format is correct
    if (filterQueryParam && Object.keys(filterQueryParam).length > 0 && gsi) {
        return Object.assign({ index: gsi, sortKey: key }, filterQueryParam);
    }
    else {
        throw Boom.badRequest('Filter contains invalid format.');
    }
}
exports.getFilterQueryParams = getFilterQueryParams;
/************************************************************
 * Creates a sort request object into a QueryParam object to be consumed by dynamoDB
 * @param sort - sort request property object
 * @param gsiPropertyNames - field names on pascal case format to retrieve gsi name
 * @returns QueryParams object
 ************************************************************/
function getSortQueryParams(sort, gsiNames) {
    if (!sort || Object.keys(sort).length === 0) {
        return {};
    }
    if (Object.keys(sort).length > 1) {
        throw Boom.badRequest('Cannot sort by more than one attribute.');
    }
    //only one entry will exist due to validation above
    const { key, value } = Object.entries(sort).map(([key, value]) => {
        return { key, value };
    })[0];
    //get GSI from gsi list in params
    const gsiMatches = gsiNames.filter((prop) => prop.replace('getResourceBy', '').toLowerCase() === key.toLowerCase());
    const gsi = gsiMatches && gsiMatches.length > 0 ? gsiMatches[0] : '';
    const forward = value === 'asc';
    //only return when format is correct
    if (gsiMatches && gsi) {
        return {
            index: gsi,
            sortKey: key,
            forward
        };
    }
    else {
        throw Boom.badRequest('Sort contains invalid format.');
    }
}
exports.getSortQueryParams = getSortQueryParams;
//# sourceMappingURL=queryParamsFiltersUtils.js.map