"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.externalIdRegExp = exports.externalIdMessage = exports.hostingAccountHandlerRoleArnMaxLength = exports.hostingAccountHandlerRoleArnRegExp = exports.hostingAccountHandlerRoleArnMessage = exports.envMgmtRoleArnMaxLength = exports.envMgmtRoleArnMessage = exports.envMgmtRoleArnRegExp = exports.datasetIdRegex = exports.userIdRegex = exports.sshKeyIdRegex = exports.lengthValidationMessage = exports.betweenFilterMessage = exports.urlFilterMaxLength = exports.requiredMessage = exports.invalidEmailMessage = exports.invalidIdMessage = exports.nonEmptyMessage = exports.accountIdRegex = exports.costCenterIdRegex = exports.envIdRegex = exports.projIdRegex = exports.etcIdRegex = exports.awsRegionRegex = exports.awsRegionMessage = exports.awsAccountIdRegExp = exports.awsAccountIdMessage = exports.etIdRegex = exports.validSshKeyUuidRegExpAsString = exports.groupIDRegExpAsString = exports.validRolesRegExpAsString = exports.envTypeConfigIdRegExpString = exports.envTypeIdRegExpString = exports.provisionArtifactIdRegExpString = exports.productIdRegExpString = exports.uuidRegExpAsString = exports.swbDescriptionMaxLength = exports.swbDescriptionRegExp = exports.swbDescriptionMessage = exports.personNameMaxLength = exports.personNameRegExp = exports.personNameMessage = exports.swbNameMaxLength = exports.swbNameRegExp = exports.swbNameMessage = exports.nonHtmlRegExp = exports.nonHTMLMessage = exports.uuidWithLowercasePrefixRegExp = exports.uuidRegExp = exports.uuidWithLowercasePrefix = void 0;
const uuid_1 = require("uuid");
const resourceTypeToKey_1 = __importDefault(require("../constants/resourceTypeToKey"));
function uuidWithLowercasePrefix(prefix) {
    return `${prefix.toLowerCase()}-${(0, uuid_1.v4)()}`;
}
exports.uuidWithLowercasePrefix = uuidWithLowercasePrefix;
const emtpyStringAsString = '^$';
const uuidRegExpAsString = '[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}';
exports.uuidRegExpAsString = uuidRegExpAsString;
const nonHTMLMessage = 'must not contain any of <>{}';
exports.nonHTMLMessage = nonHTMLMessage;
const nonHtmlRegExpAsString = '^([^<>{}]*)$';
const swbNameMessage = 'must contain only letters, numbers, hyphens, underscores, and periods';
exports.swbNameMessage = swbNameMessage;
const swbNameRegExpAsString = ['^[A-Za-z0-9-_.]+$', emtpyStringAsString].join('|');
const swbNameMaxLength = 112;
exports.swbNameMaxLength = swbNameMaxLength;
const personNameMessage = 'must contain only letters, spaces, numbers, hyphens, and periods';
exports.personNameMessage = personNameMessage;
const personNameRegExpAsString = '^[A-Za-z0-9-. ]+$';
const personNameMaxLength = 50;
exports.personNameMaxLength = personNameMaxLength;
const swbDescriptionMessage = 'must contain only letters, numbers, hyphens, underscores, periods, and spaces';
exports.swbDescriptionMessage = swbDescriptionMessage;
const swbDescriptionRegExpAsString = ['^[A-Za-z0-9-_. ]+$', emtpyStringAsString].join('|');
const swbDescriptionMaxLength = 400;
exports.swbDescriptionMaxLength = swbDescriptionMaxLength;
const externalIdMessage = 'must contain only letters, numbers, hyphens, underscores, plus, equal, comma, period, at (@), colon (:), and forward slash (/). String length must be between 2 and 400 characters inclusively';
exports.externalIdMessage = externalIdMessage;
const externalIdRegExpAsString = '^[A-Za-z0-9-_+=,.@:\\/]{2,400}$';
const nonEmptyMessage = 'optional, but cannot be empty if included';
exports.nonEmptyMessage = nonEmptyMessage;
const invalidIdMessage = 'Invalid ID';
exports.invalidIdMessage = invalidIdMessage;
const invalidEmailMessage = 'Invalid Email';
exports.invalidEmailMessage = invalidEmailMessage;
const requiredMessage = 'Required';
exports.requiredMessage = requiredMessage;
const urlFilterMaxLength = 128;
exports.urlFilterMaxLength = urlFilterMaxLength;
const betweenFilterMessage = 'value1 must be less than or equal to value2';
exports.betweenFilterMessage = betweenFilterMessage;
const groupIDRegExpAsString = '\\S{1,128}';
exports.groupIDRegExpAsString = groupIDRegExpAsString;
const awsAccountIdMessage = 'must be a 12 digit number';
exports.awsAccountIdMessage = awsAccountIdMessage;
const awsAccountIdRegExpAsString = '^[0-9]{12}$';
const envMgmtRoleArnMessage = 'must be a valid envMgmtRoleArn';
exports.envMgmtRoleArnMessage = envMgmtRoleArnMessage;
const envMgmtRoleArnRegExpAsString = '^arn:aws:iam::[0-9]{12}:role\\/[\\w-]+-env-mgmt$';
const envMgmtRoleArnMaxLength = 400;
exports.envMgmtRoleArnMaxLength = envMgmtRoleArnMaxLength;
const hostingAccountHandlerRoleArnMessage = 'must be a valid hostingAccountHandlerRoleArn';
exports.hostingAccountHandlerRoleArnMessage = hostingAccountHandlerRoleArnMessage;
const hostingAccountHandlerRoleArnRegExpAsString = '^arn:aws:iam::[0-9]{12}:role\\/[\\w-]+hosting-account-role$';
const hostingAccountHandlerRoleArnMaxLength = 400;
exports.hostingAccountHandlerRoleArnMaxLength = hostingAccountHandlerRoleArnMaxLength;
const awsRegionMessage = 'must be valid AWS region';
exports.awsRegionMessage = awsRegionMessage;
const awsRegionRegExpAsString = '^(us|ap|ca|cn|eu|sa)-(central|(north|south)?(east|west)?)-\\d$';
const productIdRegExpString = 'prod-[0-9a-zA-Z]{13}';
exports.productIdRegExpString = productIdRegExpString;
const provisionArtifactIdRegExpString = 'pa-[0-9a-zA-Z]{13}';
exports.provisionArtifactIdRegExpString = provisionArtifactIdRegExpString;
const validSshKeyUuidRegExpAsString = '[0-9a-f]{64}';
exports.validSshKeyUuidRegExpAsString = validSshKeyUuidRegExpAsString;
const envTypeIdRegExpString = `^${resourceTypeToKey_1.default.envType.toLowerCase()}-${productIdRegExpString},${provisionArtifactIdRegExpString}$`;
exports.envTypeIdRegExpString = envTypeIdRegExpString;
const envTypeConfigIdRegExpString = `^${resourceTypeToKey_1.default.envTypeConfig.toLowerCase()}-${uuidRegExpAsString}$`;
exports.envTypeConfigIdRegExpString = envTypeConfigIdRegExpString;
const projIdRegExpString = `^${resourceTypeToKey_1.default.project.toLowerCase()}-${uuidRegExpAsString}$`;
const envIdRegExpString = `^${resourceTypeToKey_1.default.environment.toLowerCase()}-${uuidRegExpAsString}$`;
const costCenterIdRegExpString = `^${resourceTypeToKey_1.default.costCenter.toLowerCase()}-${uuidRegExpAsString}$`;
const accountIdRegExpString = `^${resourceTypeToKey_1.default.account.toLowerCase()}-${uuidRegExpAsString}$`;
const datasetIdRegExpString = `^${resourceTypeToKey_1.default.dataset.toLowerCase()}-${uuidRegExpAsString}$`;
const sshKeyIdRegExpString = `^${resourceTypeToKey_1.default.sshKey.toLowerCase()}-${validSshKeyUuidRegExpAsString}$`;
const userIdRegExpString = `^${uuidRegExpAsString}$`;
// eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
const uuidRegExp = new RegExp(uuidRegExpAsString);
exports.uuidRegExp = uuidRegExp;
function lengthValidationMessage(length) {
    return `Input must be ${length} characters or less`;
}
exports.lengthValidationMessage = lengthValidationMessage;
function uuidWithLowercasePrefixRegExp(prefix) {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(`${prefix.toLowerCase()}-${uuidRegExpAsString}$`);
}
exports.uuidWithLowercasePrefixRegExp = uuidWithLowercasePrefixRegExp;
function nonHtmlRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(nonHtmlRegExpAsString);
}
exports.nonHtmlRegExp = nonHtmlRegExp;
function swbNameRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(swbNameRegExpAsString);
}
exports.swbNameRegExp = swbNameRegExp;
function personNameRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(personNameRegExpAsString);
}
exports.personNameRegExp = personNameRegExp;
function swbDescriptionRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(swbDescriptionRegExpAsString);
}
exports.swbDescriptionRegExp = swbDescriptionRegExp;
function etIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(envTypeIdRegExpString);
}
exports.etIdRegex = etIdRegex;
function etcIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(envTypeConfigIdRegExpString);
}
exports.etcIdRegex = etcIdRegex;
function projIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(projIdRegExpString);
}
exports.projIdRegex = projIdRegex;
function datasetIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(datasetIdRegExpString);
}
exports.datasetIdRegex = datasetIdRegex;
function envIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(envIdRegExpString);
}
exports.envIdRegex = envIdRegex;
function costCenterIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(costCenterIdRegExpString);
}
exports.costCenterIdRegex = costCenterIdRegex;
function accountIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(accountIdRegExpString);
}
exports.accountIdRegex = accountIdRegex;
function externalIdRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(externalIdRegExpAsString);
}
exports.externalIdRegExp = externalIdRegExp;
function awsRegionRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(awsRegionRegExpAsString);
}
exports.awsRegionRegex = awsRegionRegex;
function awsAccountIdRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(awsAccountIdRegExpAsString);
}
exports.awsAccountIdRegExp = awsAccountIdRegExp;
function envMgmtRoleArnRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(envMgmtRoleArnRegExpAsString);
}
exports.envMgmtRoleArnRegExp = envMgmtRoleArnRegExp;
function hostingAccountHandlerRoleArnRegExp() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(hostingAccountHandlerRoleArnRegExpAsString);
}
exports.hostingAccountHandlerRoleArnRegExp = hostingAccountHandlerRoleArnRegExp;
function sshKeyIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(sshKeyIdRegExpString);
}
exports.sshKeyIdRegex = sshKeyIdRegex;
function userIdRegex() {
    // eslint-disable-next-line @rushstack/security/no-unsafe-regexp,security/detect-non-literal-regexp
    return new RegExp(userIdRegExpString);
}
exports.userIdRegex = userIdRegex;
const validRolesRegExpAsString = '(ProjectAdmin|Researcher)';
exports.validRolesRegExpAsString = validRolesRegExpAsString;
//# sourceMappingURL=textUtil.js.map