"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.z = exports.getPaginationParser = exports.validateAndParse = void 0;
const Boom = __importStar(require("@hapi/boom"));
const zod_1 = require("zod");
Object.defineProperty(exports, "z", { enumerable: true, get: function () { return zod_1.z; } });
const textUtil_1 = require("./textUtil");
/**
 * validate the field is required with min length 1
 */
zod_1.z.ZodString.prototype.required = function () {
    return this.min(1, { message: textUtil_1.requiredMessage });
};
zod_1.z.ZodString.prototype.swbId = function (prefix) {
    return this.regex((0, textUtil_1.uuidWithLowercasePrefixRegExp)(prefix), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.nonHTML = function () {
    return this.regex((0, textUtil_1.nonHtmlRegExp)(), { message: textUtil_1.nonHTMLMessage });
};
zod_1.z.ZodString.prototype.swbName = function () {
    return this.max(textUtil_1.swbNameMaxLength, {
        message: (0, textUtil_1.lengthValidationMessage)(textUtil_1.swbNameMaxLength)
    }).regex((0, textUtil_1.swbNameRegExp)(), { message: textUtil_1.swbNameMessage });
};
zod_1.z.ZodString.prototype.personName = function () {
    return this.max(textUtil_1.personNameMaxLength, {
        message: (0, textUtil_1.lengthValidationMessage)(textUtil_1.personNameMaxLength)
    }).regex((0, textUtil_1.personNameRegExp)(), { message: textUtil_1.personNameMessage });
};
zod_1.z.ZodString.prototype.swbDescription = function () {
    return this.max(textUtil_1.swbDescriptionMaxLength, {
        message: (0, textUtil_1.lengthValidationMessage)(textUtil_1.swbDescriptionMaxLength)
    }).regex((0, textUtil_1.swbDescriptionRegExp)(), { message: textUtil_1.swbDescriptionMessage });
};
zod_1.z.ZodString.prototype.etId = function () {
    return this.regex((0, textUtil_1.etIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.etcId = function () {
    return this.regex((0, textUtil_1.etcIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.projId = function () {
    return this.regex((0, textUtil_1.projIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.datasetId = function () {
    return this.regex((0, textUtil_1.datasetIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.envId = function () {
    return this.regex((0, textUtil_1.envIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.costCenterId = function () {
    return this.regex((0, textUtil_1.costCenterIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.accountId = function () {
    return this.regex((0, textUtil_1.accountIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.externalId = function () {
    return this.regex((0, textUtil_1.externalIdRegExp)(), { message: textUtil_1.externalIdMessage });
};
zod_1.z.ZodString.prototype.sshKeyId = function () {
    return this.regex((0, textUtil_1.sshKeyIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
zod_1.z.ZodString.prototype.userId = function () {
    return this.regex((0, textUtil_1.userIdRegex)(), { message: textUtil_1.invalidIdMessage });
};
/**
 * validate the field is optional but should be nonEmpty with min length 1 if provided
 */
zod_1.z.ZodString.prototype.optionalNonEmpty = function () {
    // field should be nonEmpty but is optional
    return this.min(1, { message: textUtil_1.nonEmptyMessage }).optional();
};
zod_1.z.ZodString.prototype.awsAccountId = function () {
    return this.regex((0, textUtil_1.awsAccountIdRegExp)(), { message: textUtil_1.awsAccountIdMessage });
};
zod_1.z.ZodString.prototype.envMgmtRoleArn = function () {
    return this.max(textUtil_1.envMgmtRoleArnMaxLength, {
        message: (0, textUtil_1.lengthValidationMessage)(textUtil_1.envMgmtRoleArnMaxLength)
    }).regex((0, textUtil_1.envMgmtRoleArnRegExp)(), { message: textUtil_1.envMgmtRoleArnMessage });
};
zod_1.z.ZodString.prototype.hostingAccountHandlerRoleArn = function () {
    return this.max(textUtil_1.hostingAccountHandlerRoleArnMaxLength, {
        message: (0, textUtil_1.lengthValidationMessage)(textUtil_1.hostingAccountHandlerRoleArnMaxLength)
    }).regex((0, textUtil_1.hostingAccountHandlerRoleArnRegExp)(), { message: textUtil_1.hostingAccountHandlerRoleArnMessage });
};
zod_1.z.ZodString.prototype.awsRegion = function () {
    return this.regex((0, textUtil_1.awsRegionRegex)(), { message: textUtil_1.awsRegionMessage });
};
function getPaginationParser(minPageSize = 1, maxPageSize = 100) {
    return {
        pageSize: zod_1.z
            .string()
            .transform((pageSizeString, ctx) => {
            const pageSize = parseInt(pageSizeString);
            if (isNaN(pageSize)) {
                ctx.addIssue({
                    code: zod_1.z.ZodIssueCode.custom,
                    message: 'Must be a number'
                });
                return zod_1.z.NEVER;
            }
            if (pageSize < minPageSize || pageSize > maxPageSize) {
                ctx.addIssue({
                    code: zod_1.z.ZodIssueCode.custom,
                    message: `Must be Between ${minPageSize} and ${maxPageSize}`
                });
                return zod_1.z.NEVER;
            }
            return parseInt(pageSizeString);
        })
            .optional(),
        paginationToken: zod_1.z.string().optional()
    };
}
exports.getPaginationParser = getPaginationParser;
function validateAndParse(parser, data) {
    const parsed = parser.safeParse(data);
    if (parsed.success) {
        return parsed.data;
    }
    const errorMessages = parsed.error.issues.map((issue) => {
        return `${issue.path.join('.')}: ${issue.message}`;
    });
    throw Boom.badRequest(errorMessages.reduce((fullMessage, message) => {
        return `${fullMessage}. ${message}`;
    }));
}
exports.validateAndParse = validateAndParse;
//# sourceMappingURL=validatorHelper.js.map